/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui;

import javax.swing.JButton;
import javax.swing.JToggleButton;
import javax.swing.JToolBar;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * The Class ToolBar.
 */
public class ToolBar extends JToolBar {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 3146746580753998589L;

	/** The select repository. */
	private JButton selectRepository;

	/** The refresh repository. */
	private JButton refreshRepository;

	/** The preferences. */
	private JButton preferences;

	/** The show navigator. */
	private JToggleButton showNavigator;

	/** The show file properties. */
	private JToggleButton showFileProperties;

	/** The show audio scrobbler. */
	private JToggleButton showAudioScrobbler;

	/** The stats. */
	private JButton stats;

	/** The rip cd. */
	private JButton ripCD;

	/**
	 * Instantiates a new tool bar.
	 */
	public ToolBar() {
		super();
		setFloatable(false);
		setButtons();
	}

	/**
	 * Gets the preferences.
	 * 
	 * @return the preferences
	 */
	public JButton getPreferences() {
		return preferences;
	}

	/**
	 * Gets the refresh repository.
	 * 
	 * @return the refresh repository
	 */
	public JButton getRefreshRepository() {
		return refreshRepository;
	}

	/**
	 * Gets the rip cd.
	 * 
	 * @return the rip cd
	 */
	public JButton getRipCD() {
		return ripCD;
	}

	/**
	 * Gets the select repository.
	 * 
	 * @return the select repository
	 */
	public JButton getSelectRepository() {
		return selectRepository;
	}

	/**
	 * Gets the show audio scrobbler.
	 * 
	 * @return the show audio scrobbler
	 */
	public JToggleButton getShowAudioScrobbler() {
		return showAudioScrobbler;
	}

	/**
	 * Gets the show file properties.
	 * 
	 * @return the show file properties
	 */
	public JToggleButton getShowFileProperties() {
		return showFileProperties;
	}

	/**
	 * Gets the show navigator.
	 * 
	 * @return the show navigator
	 */
	public JToggleButton getShowNavigator() {
		return showNavigator;
	}

	/**
	 * Gets the stats.
	 * 
	 * @return the stats
	 */
	public JButton getStats() {
		return stats;
	}

	/**
	 * Sets the buttons.
	 */
	private void setButtons() {
		selectRepository = new JButton(ImageLoader.FOLDER);
		selectRepository.setToolTipText(LanguageTool.getString("SELECT_REPOSITORY"));
		add(selectRepository);
		refreshRepository = new JButton(ImageLoader.REFRESH);
		refreshRepository.setToolTipText(LanguageTool.getString("REFRESH_REPOSITORY"));
		add(refreshRepository);
		addSeparator();
		preferences = new JButton(ImageLoader.PREFS);
		preferences.setToolTipText(LanguageTool.getString("PREFERENCES"));
		add(preferences);
		addSeparator();
		showNavigator = new JToggleButton(ImageLoader.NAVIGATE);
		showNavigator.setToolTipText(LanguageTool.getString("SHOW_NAVIGATION_PANEL"));
		add(showNavigator);
		showFileProperties = new JToggleButton(ImageLoader.INFO);
		showFileProperties.setToolTipText(LanguageTool.getString("SHOW_SONG_PROPERTIES"));
		add(showFileProperties);
		showAudioScrobbler = new JToggleButton(ImageLoader.NETWORK_LITTLE);
		showAudioScrobbler.setToolTipText(LanguageTool.getString("SHOW_AUDIOSCROBBLER"));
		add(showAudioScrobbler);
		addSeparator();
		stats = new JButton(ImageLoader.STATS);
		stats.setToolTipText(LanguageTool.getString("STATS"));
		add(stats);
		addSeparator();
		ripCD = new JButton(ImageLoader.CD_AUDIO_TINY);
		ripCD.setToolTipText(LanguageTool.getString("RIP_CD"));
		add(ripCD);
	}

}
