/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.model;

import java.util.ArrayList;
import java.util.List;

import javax.swing.event.TableModelEvent;
import javax.swing.event.TableModelListener;
import javax.swing.table.TableModel;

import net.sourceforge.atunes.kernel.Kernel;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationController;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationControllerViews;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationControllerState.ViewMode;
import net.sourceforge.atunes.kernel.handlers.FavoritesHandler;
import net.sourceforge.atunes.kernel.modules.podcast.PodcastFeedEntry;
import net.sourceforge.atunes.kernel.modules.radio.Radio;
import net.sourceforge.atunes.kernel.modules.repository.audio.AudioFile;
import net.sourceforge.atunes.model.AudioObject;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * The Class NavigationTableModel.
 * 
 * @author fleax
 */
public class NavigationTableModel implements TableModel {

	/** The Constant NO_PROPERTIES. */
	public static final int NO_PROPERTIES = 0;

	/** The Constant FAVORITE. */
	public static final int FAVORITE = 1;

	/** The Constant NOT_LISTENED_ENTRY. */
	public static final int NOT_LISTENED_ENTRY = 2;

	/** The Constant DOWNLOADED_ENTRY. */
	public static final int DOWNLOADED_ENTRY = 3;

	/** The Constant OLD_ENTRY. */
	public static final int OLD_ENTRY = 4;

	/** The controller. */
	private NavigationController controller;

	/** The songs. */
	private List<AudioObject> songs;

	/** The listeners. */
	private List<TableModelListener> listeners;

	/**
	 * Instantiates a new navigation table model.
	 * 
	 * @param controller
	 *            the controller
	 */
	public NavigationTableModel(NavigationController controller) {
		this.controller = controller;
		songs = new ArrayList<AudioObject>();
		listeners = new ArrayList<TableModelListener>();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.table.TableModel#addTableModelListener(javax.swing.event.TableModelListener)
	 */
	@Override
	public void addTableModelListener(TableModelListener l) {
		listeners.add(l);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.table.TableModel#getColumnClass(int)
	 */
	@Override
	public Class<?> getColumnClass(int columnIndex) {
		if (columnIndex == 0)
			return Integer.class;
		else if (columnIndex == 1) {
			if (controller.getState().getNavigationView() == NavigationControllerViews.PODCAST_FEED_VIEW) {
				return Integer.class;
			}
			return String.class;
		} else if (columnIndex == 2) {
			if (controller.getState().getNavigationView() == NavigationControllerViews.PODCAST_FEED_VIEW) {
				return Integer.class;
			}
			return Long.class;
		} else if (columnIndex == 3) {
			if (controller.getState().getNavigationView() == NavigationControllerViews.PODCAST_FEED_VIEW) {
				return String.class;
			}
			return Long.class;
		} else {
			return Long.class;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.table.TableModel#getColumnCount()
	 */
	@Override
	public int getColumnCount() {
		if (controller.getState().getNavigationView() == NavigationControllerViews.RADIO_VIEW) {
			return 2;
		} else if (controller.getState().getNavigationView() == NavigationControllerViews.PODCAST_FEED_VIEW) {
			return 5;
		}
		return 3;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.table.TableModel#getColumnName(int)
	 */
	@Override
	public String getColumnName(int columnIndex) {
		int view = controller.getState().getNavigationView();
		if (columnIndex == 0)
			return "";
		else if (columnIndex == 2) {
			if (view != NavigationControllerViews.PODCAST_FEED_VIEW) {
				return LanguageTool.getString("DURATION");
			}
			return "";
		} else if (columnIndex == 1) {
			if ((view == NavigationControllerViews.REPOSITORY_VIEW && controller.getState().getViewMode() != ViewMode.FOLDER) || view == NavigationControllerViews.FAVORITE_VIEW
					|| (view == NavigationControllerViews.DEVICE_VIEW && controller.getState().getViewMode() != ViewMode.FOLDER))
				return LanguageTool.getString("TITLE");
			else if (view == NavigationControllerViews.PODCAST_FEED_VIEW)
				return "";
			else if (view != NavigationControllerViews.RADIO_VIEW)
				return LanguageTool.getString("FILE");
			else
				return LanguageTool.getString("URL");
		} else if (columnIndex == 3) {
			if (view != NavigationControllerViews.PODCAST_FEED_VIEW) {
				return LanguageTool.getString("DURATION");
			}
			return LanguageTool.getString("PODCAST_ENTRIES");

		} else if (columnIndex == 4) {
			if (view == NavigationControllerViews.PODCAST_FEED_VIEW) {
				return LanguageTool.getString("DURATION");
			}
		}
		return "";
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.table.TableModel#getRowCount()
	 */
	@Override
	public int getRowCount() {
		return songs.size();
	}

	/**
	 * Gets the song at.
	 * 
	 * @param row
	 *            the row
	 * 
	 * @return the song at
	 */
	public AudioObject getSongAt(int row) {
		return songs.get(row);
	}

	/**
	 * Gets the songs.
	 * 
	 * @return the songs
	 */
	public List<AudioObject> getSongs() {
		return new ArrayList<AudioObject>(songs);
	}

	/**
	 * Gets the songs at.
	 * 
	 * @param rows
	 *            the rows
	 * 
	 * @return the songs at
	 */
	public List<AudioObject> getSongsAt(int[] rows) {
		List<AudioObject> result = new ArrayList<AudioObject>();
		for (int element : rows) {
			result.add(getSongAt(element));
		}
		return result;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.table.TableModel#getValueAt(int, int)
	 */
	@SuppressWarnings("boxing")
	@Override
	public Object getValueAt(int rowIndex, int columnIndex) {
		AudioObject ao = songs.get(rowIndex);

		if (ao instanceof Radio) {
			if (columnIndex == 0)
				return 0;
			else if (columnIndex == 1) {
				return ao.getUrl();
			} else
				return Long.valueOf(0);
		} else if (ao instanceof PodcastFeedEntry) {
			if (columnIndex == 0) {
				return ((PodcastFeedEntry) ao).isListened() ? NO_PROPERTIES : NOT_LISTENED_ENTRY;
			} else if (columnIndex == 1) {
				return ((PodcastFeedEntry) ao).isDownloaded() ? DOWNLOADED_ENTRY : NO_PROPERTIES;
			} else if (columnIndex == 2) {
				return ((PodcastFeedEntry) ao).isOld() ? OLD_ENTRY : NO_PROPERTIES;
			} else if (columnIndex == 3) {
				return ao.getTitleOrFileName();
			} else if (columnIndex == 4) {
				return ao.getDuration();
			}
		} else if (ao instanceof AudioFile) {
			if (columnIndex == 0) {
				return Kernel.getInstance().state.isShowFavoritesInNavigator() && FavoritesHandler.getInstance().getFavoriteSongs().contains(ao) ? FAVORITE : NO_PROPERTIES;
			} else if (columnIndex == 1) {
				if ((controller.getState().getNavigationView() == NavigationControllerViews.REPOSITORY_VIEW && controller.getState().getViewMode() != ViewMode.FOLDER)
						|| controller.getState().getNavigationView() == NavigationControllerViews.FAVORITE_VIEW || controller.getState().getViewMode() != ViewMode.FOLDER)
					return ao.getTitleOrFileName();
				return ((AudioFile) ao).getName();
			} else {
				return ao.getDuration();
			}
		}
		return null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.table.TableModel#isCellEditable(int, int)
	 */
	@Override
	public boolean isCellEditable(@SuppressWarnings("unused")
	int rowIndex, @SuppressWarnings("unused")
	int columnIndex) {
		return false;
	}

	/**
	 * Refresh.
	 */
	public void refresh() {
		TableModelEvent event = new TableModelEvent(this, 0, this.getRowCount() - 1, TableModelEvent.ALL_COLUMNS, TableModelEvent.UPDATE);
		for (int i = 0; i < listeners.size(); i++)
			listeners.get(i).tableChanged(event);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.table.TableModel#removeTableModelListener(javax.swing.event.TableModelListener)
	 */
	@Override
	public void removeTableModelListener(TableModelListener l) {
		listeners.remove(l);
	}

	/**
	 * Sets the songs.
	 * 
	 * @param songs
	 *            the new songs
	 */
	public void setSongs(List<AudioObject> songs) {
		this.songs = songs;
		TableModelEvent event = new TableModelEvent(this, -1, this.getRowCount() - 1, TableModelEvent.ALL_COLUMNS, TableModelEvent.INSERT);
		for (int i = 0; i < listeners.size(); i++)
			listeners.get(i).tableChanged(event);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.table.TableModel#setValueAt(java.lang.Object, int, int)
	 */
	@Override
	public void setValueAt(@SuppressWarnings("unused")
	Object aValue, @SuppressWarnings("unused")
	int rowIndex, @SuppressWarnings("unused")
	int columnIndex) {
		// Nothing to do
	}

}
