/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.substance;

import org.jvnet.substance.border.ClassicBorderPainter;
import org.jvnet.substance.button.ClassicButtonShaper;
import org.jvnet.substance.painter.AlphaControlBackgroundComposite;
import org.jvnet.substance.painter.GlassGradientPainter;
import org.jvnet.substance.painter.decoration.ArcDecorationPainter;
import org.jvnet.substance.painter.decoration.DecorationAreaType;
import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
import org.jvnet.substance.skin.SubstanceAbstractSkin;
import org.jvnet.substance.theme.SubstanceComplexTheme;
import org.jvnet.substance.theme.SubstanceEbonyTheme;
import org.jvnet.substance.theme.SubstanceTheme;
import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
import org.jvnet.substance.utils.ComponentState;
import org.jvnet.substance.watermark.SubstanceNoneWatermark;

public class SubstanceATunesDarkSkin extends SubstanceAbstractSkin {

	/** Display name for <code>this</code> skin. */
	private static final String NAME = "aTunes Dark";

	/**
	 * Creates a new skin.
	 */
	@SuppressWarnings("deprecation")
	public SubstanceATunesDarkSkin() {

		SubstanceTheme activeTheme = new SubstanceEbonyTheme();
		SubstanceTheme defaultTheme = new SubstanceEbonyTheme();
		SubstanceTheme disabledTheme = activeTheme.getDisabledTheme();
		SubstanceTheme activeTitleTheme = activeTheme.getActiveTitlePaneTheme();

		SubstanceComplexTheme complexTheme = new SubstanceComplexTheme(NAME, ThemeKind.COLD, activeTheme, defaultTheme, disabledTheme, activeTitleTheme);
		complexTheme.registerDecorationAreaTheme(activeTheme, false, DecorationAreaType.PRIMARY_TITLE_PANE, DecorationAreaType.SECONDARY_TITLE_PANE, DecorationAreaType.HEADER,
				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
		complexTheme.registerComponentHighlightStateTheme(activeTheme, 0.6f, ComponentState.ROLLOVER_UNSELECTED);
		complexTheme.registerComponentHighlightStateTheme(activeTheme, 0.8f, ComponentState.SELECTED);
		complexTheme.registerComponentHighlightStateTheme(activeTheme, 0.95f, ComponentState.ROLLOVER_SELECTED);
		complexTheme.registerComponentHighlightStateTheme(activeTheme, 0.8f, ComponentState.ARMED, ComponentState.ROLLOVER_ARMED);

		this.theme = complexTheme;
		this.buttonShaper = new ClassicButtonShaper();
		this.watermark = new SubstanceNoneWatermark();
		this.gradientPainter = new GlassGradientPainter();
		this.borderPainter = new ClassicBorderPainter();
		this.decorationPainter = new ArcDecorationPainter();
		this.highlightPainter = new ClassicHighlightPainter();
		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jvnet.substance.skin.SubstanceSkin#getDisplayName()
	 */
	@Override
	public String getDisplayName() {
		return "aTunes Dark skin";
	}

}
