/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.views.dialogs.editPreferences;

import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.HashMap;
import java.util.Map;

import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;

import net.sourceforge.atunes.utils.LanguageTool;

/**
 * The Class NavigatorPanel.
 */
public class NavigatorPanel extends PreferencesPanel {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -4315748284461119970L;

	/** The show favorites. */
	private JCheckBox showFavorites;

	/** The show album tool tip. */
	JCheckBox showAlbumToolTip;

	/** The album tool tip delay. */
	JComboBox albumToolTipDelay;

	/** The use smart tag view sorting. */
	private JCheckBox useSmartTagViewSorting;

	/**
	 * Check box to set navigator tabs at left (selected) or top (unselected)
	 */
	private JCheckBox showNavigatorTabsAtLeft;

	/**
	 * Check box to set navigator tabs text (selected) or not (unselected)
	 */
	private JCheckBox showNavigatorTabsText;

	/**
	 * Instantiates a new navigator panel.
	 */
	@SuppressWarnings("boxing")
	public NavigatorPanel() {
		super();
		showFavorites = new JCheckBox(LanguageTool.getString("SHOW_FAVORITES"));
		showAlbumToolTip = new JCheckBox(LanguageTool.getString("SHOW_ALBUM_TOOLTIP"));
		final JLabel label = new JLabel(LanguageTool.getString("ALBUM_TOOLTIP_DELAY"));
		albumToolTipDelay = new JComboBox(new Integer[] { 1, 2, 3, 4, 5 });
		showAlbumToolTip.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(@SuppressWarnings("unused")
			ActionEvent arg0) {
				label.setEnabled(showAlbumToolTip.isSelected());
				albumToolTipDelay.setEnabled(showAlbumToolTip.isSelected());
			}
		});
		useSmartTagViewSorting = new JCheckBox(LanguageTool.getString("USE_SMART_TAG_VIEW_SORTING"));
		showNavigatorTabsAtLeft = new JCheckBox(LanguageTool.getString("SHOW_NAVIGATION_TABS_AT_LEFT"));
		showNavigatorTabsText = new JCheckBox(LanguageTool.getString("SHOW_NAVIGATION_TABS_TEXT"));
		GridBagConstraints c = new GridBagConstraints();
		c.gridx = 0;
		c.gridy = 0;
		c.weightx = 1;
		c.fill = GridBagConstraints.HORIZONTAL;
		c.anchor = GridBagConstraints.NORTH;
		add(showFavorites, c);
		c.gridy = 1;
		add(showAlbumToolTip, c);
		c.gridy = 2;
		c.insets = new Insets(0, 30, 0, 0);
		add(label, c);
		c.gridx = 1;
		c.insets = new Insets(0, 0, 0, 0);
		add(albumToolTipDelay, c);
		c.gridx = 0;
		c.gridy = 3;
		add(useSmartTagViewSorting, c);
		c.gridy = 4;
		add(showNavigatorTabsAtLeft, c);
		c.gridy = 5;
		c.weighty = 1;
		add(showNavigatorTabsText, c);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.gui.views.dialogs.editPreferences.PreferencesPanel#getResult()
	 */
	@SuppressWarnings("boxing")
	@Override
	public Map<String, Object> getResult() {
		Map<String, Object> result = new HashMap<String, Object>();
		result.put(LanguageTool.getString("SHOW_FAVORITES"), showFavorites.isSelected());
		result.put(LanguageTool.getString("SHOW_ALBUM_TOOLTIP"), showAlbumToolTip.isSelected());
		result.put(LanguageTool.getString("ALBUM_TOOLTIP_DELAY"), albumToolTipDelay.getSelectedItem());
		result.put(LanguageTool.getString("USE_SMART_TAG_VIEW_SORTING"), useSmartTagViewSorting.isSelected());
		result.put(LanguageTool.getString("SHOW_NAVIGATION_TABS_AT_LEFT"), showNavigatorTabsAtLeft.isSelected());
		result.put(LanguageTool.getString("SHOW_NAVIGATION_TABS_TEXT"), showNavigatorTabsText.isSelected());
		return result;
	}

	/**
	 * Sets the album tool tip delay.
	 * 
	 * @param time
	 *            the new album tool tip delay
	 */
	@SuppressWarnings("boxing")
	public void setAlbumToolTipDelay(int time) {
		albumToolTipDelay.setSelectedItem(time);
	}

	/**
	 * Sets the show album tool tip.
	 * 
	 * @param show
	 *            the new show album tool tip
	 */
	public void setShowAlbumToolTip(boolean show) {
		showAlbumToolTip.setSelected(show);
	}

	/**
	 * Sets the show favorites.
	 * 
	 * @param show
	 *            the new show favorites
	 */
	public void setShowFavorites(boolean show) {
		showFavorites.setSelected(show);
	}

	/**
	 * Sets the use smart tag view sorting.
	 * 
	 * @param use
	 *            the new use smart tag view sorting
	 */
	public void setUseSmartTagViewSorting(boolean use) {
		useSmartTagViewSorting.setSelected(use);
	}

	/**
	 * Sets property to show navigator tabs at left
	 * 
	 * @param show
	 */
	public void setShowNavigatorTabsAtLeft(boolean show) {
		showNavigatorTabsAtLeft.setSelected(show);
	}

	/**
	 * Sets property to show navigator tabs text
	 * 
	 * @param show
	 */
	public void setShowNavigatorTabsText(boolean show) {
		showNavigatorTabsText.setSelected(show);
	}

}
