/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.views.panels;

import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import javax.swing.JButton;
import javax.swing.JMenuItem;
import javax.swing.JPanel;

import net.sourceforge.atunes.gui.GuiUtils;
import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.gui.views.controls.CustomButton;
import net.sourceforge.atunes.gui.views.controls.PopUpButton;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * The Class PlayListControlsPanel.
 */
public class PlayListControlsPanel extends JPanel {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -1966827894270243002L;

	/** The search filter. */
	private JButton searchFilter;

	/** The save playlist button. */
	private JButton savePlaylistButton;

	/** The load playlist button. */
	private JButton loadPlaylistButton;

	/** The scroll playlist to current song button. */
	private JButton scrollPlaylistToCurrentSongButton;

	/** The artist button. */
	private JButton artistButton;

	/** The album button. */
	private JButton albumButton;

	/** The top button. */
	private JButton topButton;

	/** The up button. */
	private JButton upButton;

	/** The delete button. */
	private JButton deleteButton;

	/** The down button. */
	private JButton downButton;

	/** The bottom button. */
	private JButton bottomButton;

	/** The info button. */
	private JButton infoButton;

	/** The clear button. */
	private JButton clearButton;

	/** The shuffle playlist. */
	private JButton shufflePlaylist;

	/** The favorite popup. */
	private PopUpButton favoritePopup;

	/** The favorite song. */
	private JMenuItem favoriteSong;

	/** The favorite album. */
	private JMenuItem favoriteAlbum;

	/** The favorite artist. */
	private JMenuItem favoriteArtist;

	/**
	 * Instantiates a new play list controls panel.
	 */
	public PlayListControlsPanel() {
		super(new GridBagLayout());
		addContent();
	}

	/**
	 * Adds the content.
	 */
	private void addContent() {
		//sortPopup = new PopUpButton(LanguageTool.getString("OPTIONS"), PopUpButton.TOP_RIGHT);

		//sortPopup.add(arrangeColumns);

		searchFilter = new CustomButton(ImageLoader.SEARCH, null);
		searchFilter.setToolTipText(LanguageTool.getString("FILTER"));
		savePlaylistButton = new CustomButton(ImageLoader.SAVE, null);
		savePlaylistButton.setToolTipText(LanguageTool.getString("SAVE_PLAYLIST_TOOLTIP"));
		loadPlaylistButton = new CustomButton(ImageLoader.FOLDER, null);
		loadPlaylistButton.setToolTipText(LanguageTool.getString("LOAD_PLAYLIST_TOOLTIP"));

		scrollPlaylistToCurrentSongButton = new CustomButton(ImageLoader.SCROLL_PLAYLIST, null);
		scrollPlaylistToCurrentSongButton.setToolTipText(LanguageTool.getString("SCROLL_PLAYLIST_TO_CURRENT_SONG"));

		artistButton = new CustomButton(ImageLoader.ARTIST, null);
		artistButton.setEnabled(false);
		artistButton.setToolTipText(LanguageTool.getString("ARTIST_BUTTON_TOOLTIP"));
		albumButton = new CustomButton(ImageLoader.ALBUM, null);
		albumButton.setEnabled(false);
		albumButton.setToolTipText(LanguageTool.getString("ALBUM_BUTTON_TOOLTIP"));

		topButton = new CustomButton(ImageLoader.GO_TOP, null);
		topButton.setEnabled(false);
		topButton.setToolTipText(LanguageTool.getString("MOVE_TO_TOP_TOOLTIP"));
		upButton = new CustomButton(ImageLoader.GO_UP, null);
		upButton.setEnabled(false);
		upButton.setToolTipText(LanguageTool.getString("MOVE_UP_TOOLTIP"));
		deleteButton = new CustomButton(ImageLoader.REMOVE, null);
		deleteButton.setEnabled(false);
		deleteButton.setToolTipText(LanguageTool.getString("REMOVE_TOOLTIP"));
		downButton = new CustomButton(ImageLoader.GO_DOWN, null);
		downButton.setEnabled(false);
		downButton.setToolTipText(LanguageTool.getString("MOVE_DOWN_TOOLTIP"));
		bottomButton = new CustomButton(ImageLoader.GO_BOTTOM, null);
		bottomButton.setEnabled(false);
		bottomButton.setToolTipText(LanguageTool.getString("MOVE_BOTTOM_TOOLTIP"));
		infoButton = new CustomButton(ImageLoader.INFO, null);
		infoButton.setEnabled(false);
		infoButton.setToolTipText(LanguageTool.getString("INFO_BUTTON_TOOLTIP"));
		clearButton = new CustomButton(ImageLoader.CLEAR, null);
		clearButton.setEnabled(false);
		clearButton.setToolTipText(LanguageTool.getString("CLEAR_TOOLTIP"));
		shufflePlaylist = new CustomButton(ImageLoader.SHUFFLE_PLAYLIST, null);
		shufflePlaylist.setToolTipText(LanguageTool.getString("SHUFFLE_PLAYLIST"));
		favoritePopup = new PopUpButton(ImageLoader.FAVORITE, PopUpButton.TOP_LEFT);
		favoritePopup.setEnabled(false);
		favoritePopup.setToolTipText(LanguageTool.getString("FAVORITE_TOOLTIP"));
		favoriteSong = new JMenuItem(LanguageTool.getString("SET_FAVORITE_SONG"), ImageLoader.FAVORITE);
		favoriteAlbum = new JMenuItem(LanguageTool.getString("SET_FAVORITE_ALBUM"), ImageLoader.FAVORITE);
		favoriteArtist = new JMenuItem(LanguageTool.getString("SET_FAVORITE_ARTIST"), ImageLoader.FAVORITE);
		favoritePopup.add(favoriteSong);
		favoritePopup.add(favoriteAlbum);
		favoritePopup.add(favoriteArtist);

		GridBagConstraints c = new GridBagConstraints();

		c.gridx = 0;
		c.gridy = 0;
		c.insets = new Insets(1, 0, 0, 10);
		setButton(searchFilter, c);

		c.gridx = 1;
		c.gridy = 0;
		c.insets = new Insets(1, 0, 0, 0);
		setButton(savePlaylistButton, c);

		c.gridx = 2;
		c.gridy = 0;
		setButton(loadPlaylistButton, c);

		c.gridx = 3;
		c.gridy = 0;
		c.weightx = 1;
		c.anchor = GridBagConstraints.EAST;
		c.insets = new Insets(1, 0, 0, 10);
		setButton(scrollPlaylistToCurrentSongButton, c);

		c.gridx = 4;
		c.gridy = 0;
		c.weightx = 0;
		c.insets = new Insets(1, 0, 0, 0);
		setButton(artistButton, c);

		c.gridx = 5;
		c.gridy = 0;
		c.weightx = 0;
		c.insets = new Insets(1, 0, 0, 10);
		setButton(albumButton, c);

		c.gridx = 6;
		c.gridy = 0;
		c.insets = new Insets(1, 0, 0, 10);
		setButton(infoButton, c);

		c.gridx = 7;
		c.gridy = 0;
		c.insets = new Insets(1, 0, 0, 0);
		setButton(deleteButton, c);

		c.gridx = 8;
		c.gridy = 0;
		setButton(clearButton, c);

		c.gridx = 9;
		c.gridy = 0;
		setButton(topButton, c);

		c.gridx = 10;
		c.gridy = 0;
		setButton(upButton, c);

		c.gridx = 11;
		c.gridy = 0;
		setButton(downButton, c);

		c.gridx = 12;
		c.gridy = 0;
		c.weighty = 1;
		c.insets = new Insets(1, 0, 0, 10);
		setButton(bottomButton, c);

		c.gridx = 13;
		c.gridy = 0;
		c.weighty = 1;
		c.insets = new Insets(1, 0, 0, 10);
		setButton(shufflePlaylist, c);

		c.gridx = 14;
		c.gridy = 0;
		c.insets = new Insets(1, 0, 0, 0);
		setButton(favoritePopup, c);

		GuiUtils.applyComponentOrientation(favoritePopup);
	}

	/**
	 * Gets the album button.
	 * 
	 * @return the album button
	 */
	public JButton getAlbumButton() {
		return albumButton;
	}

	/**
	 * Gets the artist button.
	 * 
	 * @return the artist button
	 */
	public JButton getArtistButton() {
		return artistButton;
	}

	/**
	 * Gets the bottom button.
	 * 
	 * @return the bottom button
	 */
	public JButton getBottomButton() {
		return bottomButton;
	}

	/**
	 * Gets the clear button.
	 * 
	 * @return the clear button
	 */
	public JButton getClearButton() {
		return clearButton;
	}

	/**
	 * Gets the delete button.
	 * 
	 * @return the delete button
	 */
	public JButton getDeleteButton() {
		return deleteButton;
	}

	/**
	 * Gets the down button.
	 * 
	 * @return the down button
	 */
	public JButton getDownButton() {
		return downButton;
	}

	/**
	 * Gets the favorite album.
	 * 
	 * @return the favorite album
	 */
	public JMenuItem getFavoriteAlbum() {
		return favoriteAlbum;
	}

	/**
	 * Gets the favorite artist.
	 * 
	 * @return the favorite artist
	 */
	public JMenuItem getFavoriteArtist() {
		return favoriteArtist;
	}

	/**
	 * Gets the favorite popup.
	 * 
	 * @return the favorite popup
	 */
	public PopUpButton getFavoritePopup() {
		return favoritePopup;
	}

	/**
	 * Gets the favorite song.
	 * 
	 * @return the favorite song
	 */
	public JMenuItem getFavoriteSong() {
		return favoriteSong;
	}

	/**
	 * Gets the info button.
	 * 
	 * @return the info button
	 */
	public JButton getInfoButton() {
		return infoButton;
	}

	/**
	 * Gets the load playlist button.
	 * 
	 * @return the load playlist button
	 */
	public JButton getLoadPlaylistButton() {
		return loadPlaylistButton;
	}

	/**
	 * Gets the save playlist button.
	 * 
	 * @return the save playlist button
	 */
	public JButton getSavePlaylistButton() {
		return savePlaylistButton;
	}

	/**
	 * Gets the scroll playlist to current song button.
	 * 
	 * @return the scrollPlaylistToCurrentSongButton
	 */
	public JButton getScrollPlaylistToCurrentSongButton() {
		return scrollPlaylistToCurrentSongButton;
	}

	/**
	 * Gets the search filter.
	 * 
	 * @return the search filter
	 */
	public JButton getSearchFilter() {
		return searchFilter;
	}

	/**
	 * Gets the top button.
	 * 
	 * @return the top button
	 */
	public JButton getTopButton() {
		return topButton;
	}

	/**
	 * Gets the up button.
	 * 
	 * @return the up button
	 */
	public JButton getUpButton() {
		return upButton;
	}

	/**
	 * Gets the shuffle playlist.
	 * 
	 * @return the shuffle playlist
	 */
	public JButton getShufflePlaylist() {
		return shufflePlaylist;
	}

	/**
	 * Sets the button.
	 * 
	 * @param button
	 *            the button
	 * @param c
	 *            the c
	 */
	private void setButton(JButton button, GridBagConstraints c) {
		button.setPreferredSize(new Dimension(20, 20));
		add(button, c);
	}
}
