/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.controllers.audioScrobbler;

import java.awt.Image;
import java.util.Date;

import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

import net.sourceforge.atunes.Constants;
import net.sourceforge.atunes.gui.GuiUtils;
import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.gui.model.AudioScrobblerAlbumsTableModel;
import net.sourceforge.atunes.gui.model.AudioScrobblerArtistsTableModel;
import net.sourceforge.atunes.gui.model.AudioScrobblerTracksTableModel;
import net.sourceforge.atunes.gui.views.panels.AudioScrobblerPanel;
import net.sourceforge.atunes.kernel.Kernel;
import net.sourceforge.atunes.kernel.controllers.model.PanelController;
import net.sourceforge.atunes.kernel.handlers.AudioScrobblerServiceHandler;
import net.sourceforge.atunes.kernel.handlers.DesktopHandler;
import net.sourceforge.atunes.kernel.handlers.PlayerHandler;
import net.sourceforge.atunes.kernel.handlers.RepositoryHandler;
import net.sourceforge.atunes.kernel.modules.audioscrobbler.AudioScrobblerAlbum;
import net.sourceforge.atunes.kernel.modules.audioscrobbler.AudioScrobblerArtist;
import net.sourceforge.atunes.kernel.modules.audioscrobbler.AudioScrobblerTrack;
import net.sourceforge.atunes.kernel.modules.internetsearch.SearchFactory;
import net.sourceforge.atunes.kernel.modules.podcast.PodcastFeedEntry;
import net.sourceforge.atunes.kernel.modules.radio.Radio;
import net.sourceforge.atunes.kernel.modules.repository.SongStats;
import net.sourceforge.atunes.kernel.modules.repository.audio.AudioFile;
import net.sourceforge.atunes.kernel.utils.ClipboardFacade;
import net.sourceforge.atunes.model.AudioObject;
import net.sourceforge.atunes.utils.DateUtils;
import net.sourceforge.atunes.utils.ImageUtils;
import net.sourceforge.atunes.utils.LanguageTool;
import net.sourceforge.atunes.utils.StringUtils;
import net.sourceforge.atunes.utils.log4j.LogCategories;

/**
 * The Class AudioScrobblerController.
 */
public class AudioScrobblerController extends PanelController<AudioScrobblerPanel> {

	/** Query to use when searching for a video. */
	private String searchVideoQuery = null;

	/**
	 * Instantiates a new audio scrobbler controller.
	 * 
	 * @param panel
	 *            the panel
	 */
	public AudioScrobblerController(AudioScrobblerPanel panel) {
		super(panel);
		addBindings();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#addBindings()
	 */
	@Override
	protected void addBindings() {
		AudioScrobblerListener objListener = new AudioScrobblerListener(this);

		getPanelControlled().getTracksTable().getSelectionModel().addListSelectionListener(new ListSelectionListener() {
			@Override
			public void valueChanged(ListSelectionEvent e) {
				if (!e.getValueIsAdjusting()) {
					int selectedTrack = getPanelControlled().getTracksTable().getSelectedRow();
					AudioScrobblerTrack track = ((AudioScrobblerTracksTableModel) getPanelControlled().getTracksTable().getModel()).getTrack(selectedTrack);
					DesktopHandler.getInstance().openURL(track.getUrl());
				}
			}
		});

		getPanelControlled().getAlbumsTable().getSelectionModel().addListSelectionListener(new ListSelectionListener() {
			@Override
			public void valueChanged(ListSelectionEvent e) {
				if (!e.getValueIsAdjusting()) {
					int selectedAlbum = getPanelControlled().getAlbumsTable().getSelectedRow();
					AudioScrobblerAlbum album = ((AudioScrobblerAlbumsTableModel) getPanelControlled().getAlbumsTable().getModel()).getAlbum(selectedAlbum);
					DesktopHandler.getInstance().openURL(album.getUrl());
				}
			}
		});

		getPanelControlled().getSimilarArtistsTable().getSelectionModel().addListSelectionListener(new ListSelectionListener() {
			@Override
			public void valueChanged(ListSelectionEvent e) {
				if (!e.getValueIsAdjusting()) {
					int selectedArtist = getPanelControlled().getSimilarArtistsTable().getSelectedRow();
					AudioScrobblerArtist artist = ((AudioScrobblerArtistsTableModel) getPanelControlled().getSimilarArtistsTable().getModel()).getArtist(selectedArtist);
					DesktopHandler.getInstance().openURL(artist.getUrl());
				}
			}
		});

		getPanelControlled().getCopyLyricToClipboard().addActionListener(objListener);
		getPanelControlled().getSearchForVideo().addActionListener(objListener);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#addStateBindings()
	 */
	@Override
	protected void addStateBindings() {
		// Nothing to do
	}

	/**
	 * Clear.
	 * 
	 * @param clearArtistAndSimilar
	 *            the clear artist and similar
	 */
	public void clear(boolean clearArtistAndSimilar) {
		getLogger().debug(LogCategories.CONTROLLER, new String[] { Boolean.toString(clearArtistAndSimilar) });

		getPanelControlled().getTracksTable().removeAll();
		getPanelControlled().getAlbumPanel().setVisible(false);
		getPanelControlled().getLyricsCover().setVisible(false);
		getPanelControlled().getLyricsContainer().setText("");
		getPanelControlled().getLyricsLabel().setText("");
		getPanelControlled().getLyricsLabel().setToolTipText(null);
		getPanelControlled().getLyricsArtistLabel().setText("");
		getPanelControlled().getLyricsLastPlayDateLabel().setText("");
		getPanelControlled().getCopyLyricToClipboard().setEnabled(false);
		getPanelControlled().getLyricScrollPane().setEnabled(false);
		getPanelControlled().getSearchForVideo().setVisible(false);
		getPanelControlled().getCopyLyricToClipboard().setVisible(false);
		getPanelControlled().getLyricScrollPane().setVisible(false);

		if (clearArtistAndSimilar) {
			getPanelControlled().getArtistImageLabel().setVisible(false);
			getPanelControlled().getAlbumsPanel().setVisible(false);
			getPanelControlled().getSimilarArtistsPanel().setVisible(false);
		}
	}

	/**
	 * Clear albums container.
	 */
	public void clearAlbumsContainer() {
		getPanelControlled().getAlbumsTable().setModel(new AudioScrobblerAlbumsTableModel());
	}

	/**
	 * Clear similar artists container.
	 */
	public void clearSimilarArtistsContainer() {
		getPanelControlled().getSimilarArtistsTable().setModel(new AudioScrobblerArtistsTableModel());
	}

	/**
	 * Copies current lyric to clipboard.
	 */
	protected void copyToClipboard() {
		String sLyric = getPanelControlled().getLyricsContainer().getText();
		if (sLyric == null)
			sLyric = "";
		ClipboardFacade.copyToClipboard(sLyric);
	}

	/**
	 * Fill albums list.
	 * 
	 * @param album
	 *            the album
	 * @param cover
	 *            the cover
	 */
	void fillAlbumsList(AudioScrobblerAlbum album, Image cover) {
		album.setCover(ImageUtils.scaleImageBicubic(cover, Constants.AUDIO_SCROBBLER_IMAGE_WIDTH, Constants.AUDIO_SCROBBLER_IMAGE_HEIGHT));
		((AudioScrobblerAlbumsTableModel) getPanelControlled().getAlbumsTable().getModel()).addAlbum(album);

		getPanelControlled().getAlbumsTable().revalidate();
		getPanelControlled().getAlbumsTable().repaint();
	}

	/**
	 * Fill similar artists list.
	 * 
	 * @param artist
	 *            the artist
	 * @param img
	 *            the img
	 */
	void fillSimilarArtistsList(AudioScrobblerArtist artist, Image img) {
		artist.setImage(ImageUtils.scaleImageBicubic(img, Constants.AUDIO_SCROBBLER_IMAGE_WIDTH, Constants.AUDIO_SCROBBLER_IMAGE_HEIGHT));
		((AudioScrobblerArtistsTableModel) getPanelControlled().getSimilarArtistsTable().getModel()).addArtist(artist);

		getPanelControlled().getSimilarArtistsTable().revalidate();
		getPanelControlled().getSimilarArtistsTable().repaint();
	}

	/**
	 * Gets the panel controlled.
	 * 
	 * @return the panel controlled
	 */
	@Override
	protected AudioScrobblerPanel getPanelControlled() {
		return super.getPanelControlled();
	}

	/**
	 * Notify artist image.
	 * 
	 * @param img
	 *            the img
	 */
	public void notifyArtistImage(final Image img) {
		getLogger().debug(LogCategories.CONTROLLER);

		getPanelControlled().getArtistImageLabel().setIcon(new ImageIcon(img));
		getPanelControlled().getArtistImageLabel().setVisible(true);
	}

	/**
	 * Notify finish get album info.
	 * 
	 * @param artist
	 *            the artist
	 * @param album
	 *            the album
	 * @param img
	 *            the img
	 */
	public void notifyFinishGetAlbumInfo(final String artist, final AudioScrobblerAlbum album, final Image img) {
		getPanelControlled().getArtistLabel().setText(album != null ? album.getArtist() : artist, album != null ? album.getArtistUrl() : null);
		getPanelControlled().getAlbumLabel().setText(album != null ? album.getTitle() : LanguageTool.getString("UNKNOWN_ALBUM"), album != null ? album.getUrl() : null);
		getPanelControlled().getYearLabel().setText(album != null ? album.getYear() : "",
				album != null && album.getYear() != null ? StringUtils.getString("http://en.wikipedia.org/wiki/", album.getYear()) : null);
		if (album != null) {
			getLogger().debug(LogCategories.CONTROLLER, new String[] { album.getTitle() });
		}
		if (img != null) {
			ImageIcon image = ImageUtils.resize(new ImageIcon(img), 170, 170);
			getPanelControlled().getAlbumCoverLabel().setIcon(image);
			getPanelControlled().getLyricsCover().setIcon(image);
			getPanelControlled().getLyricsCover().setBorder(BorderFactory.createLineBorder(GuiUtils.getBorderColor()));
			getPanelControlled().getLyricsCover().setVisible(true);
		}
		getPanelControlled().getAlbumCoverLabel().setVisible(img != null);

		if (album != null) {
			getPanelControlled().getTracksTable().setModel(new AudioScrobblerTracksTableModel(album));
		}
		getPanelControlled().getAlbumPanel().setVisible(true);
	}

	/**
	 * Notify finish get albums info.
	 * 
	 * @param album
	 *            the album
	 * @param cover
	 *            the cover
	 */
	public void notifyFinishGetAlbumsInfo(final AudioScrobblerAlbum album, final Image cover) {
		getLogger().debug(LogCategories.CONTROLLER, new String[] { album.getTitle() });

		getPanelControlled().getArtistAlbumsLabel().setText(album.getArtist(), album.getArtistUrl());
		getPanelControlled().getArtistAlbumsLabel().setVisible(true);
		getPanelControlled().getAlbumsPanel().setVisible(true);
		fillAlbumsList(album, cover);
	}

	/**
	 * Notify finish get similar artist.
	 * 
	 * @param artist
	 *            the artist
	 * @param img
	 *            the img
	 */
	public void notifyFinishGetSimilarArtist(final AudioScrobblerArtist artist, final Image img) {
		getLogger().debug(LogCategories.CONTROLLER);

		getPanelControlled().getSimilarArtistsPanel().setVisible(true);
		fillSimilarArtistsList(artist, img);
	}

	/**
	 * Notify podcast.
	 * 
	 * @param entry
	 *            the entry
	 */
	public void notifyPodcast(PodcastFeedEntry entry) {
		clear(true);
		getPanelControlled().getLyricsCover().setIcon(ImageLoader.RSS);
		getPanelControlled().getLyricsCover().setBorder(BorderFactory.createEmptyBorder());
		getPanelControlled().getLyricsCover().setVisible(true);
		getPanelControlled().getLyricsLabel().setText(entry.getName());
		getPanelControlled().getLyricsLabel().setToolTipText(entry.getName());
		getPanelControlled().getLyricScrollPane().setVisible(true);
		getPanelControlled().getLyricsContainer().setText(entry.getDescription());
		getPanelControlled().getLyricsContainer().setCaretPosition(0);
		getPanelControlled().getLyricsContainer().setLineWrap(true);
	}

	/**
	 * Notify radio.
	 * 
	 * @param radio
	 *            the radio
	 */
	public void notifyRadio(Radio radio) {
		clear(true);
		getPanelControlled().getLyricsCover().setIcon(ImageLoader.RADIO);
		getPanelControlled().getLyricsCover().setBorder(BorderFactory.createEmptyBorder());
		getPanelControlled().getLyricsCover().setVisible(true);
		getPanelControlled().getLyricsLabel().setText(radio.getName());
		getPanelControlled().getLyricsArtistLabel().setText(radio.getUrl());
		getPanelControlled().getLyricScrollPane().setVisible(true);
		getPanelControlled().getLyricsContainer().setLineWrap(true);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#notifyReload()
	 */
	@Override
	protected void notifyReload() {
		// Nothing to do
	}

	/**
	 * Opens a navigator to search for video.
	 */
	public void searchForVideo() {
		if (searchVideoQuery != null)
			DesktopHandler.getInstance().openSearch(SearchFactory.getSearchForName("YouTube"), searchVideoQuery);
	}

	/**
	 * Sets the audio object info
	 * 
	 * @param audioObject
	 *            the audio object
	 */
	public void setAudioObjectInfo(AudioObject audioObject) {
		getLogger().debug(LogCategories.CONTROLLER);

		getPanelControlled().getSearchForVideo().setVisible(true);
		getPanelControlled().getCopyLyricToClipboard().setEnabled(false);
		getPanelControlled().getCopyLyricToClipboard().setVisible(true);
		getPanelControlled().getLyricsContainer().setText("");
		getPanelControlled().getLyricScrollPane().setVisible(true);
		getPanelControlled().getLyricsLabel().setText(audioObject.getTitleOrFileName());
		getPanelControlled().getLyricsArtistLabel().setText(audioObject.getArtist());

		// Get last date played
		SongStats stats = null;
		if (audioObject instanceof AudioFile) {
			stats = RepositoryHandler.getInstance().getSongStatistics((AudioFile) audioObject);
		}
		if (stats == null)
			getPanelControlled().getLyricsLastPlayDateLabel().setText(LanguageTool.getString("SONG_NEVER_PLAYED"));
		else {
			// If song is playing, take previous play, if not, take last
			Date date;
			if (PlayerHandler.getInstance().isPlaying())
				date = stats.getPreviousPlayed();
			else
				date = stats.getLastPlayed();

			// If date is null -> never player
			if (date == null)
				getPanelControlled().getLyricsLastPlayDateLabel().setText(LanguageTool.getString("SONG_NEVER_PLAYED"));
			else
				getPanelControlled().getLyricsLastPlayDateLabel().setText(StringUtils.getString(LanguageTool.getString("LAST_DATE_PLAYED"), ": ", DateUtils.toString(date)));
		}
	}

	/**
	 * Sets the lyrics.
	 * 
	 * @param audioObject
	 *            the audio object
	 * @param lyrics
	 *            the lyrics
	 */
	public void setLyrics(AudioObject audioObject, String lyrics) {
		getLogger().debug(LogCategories.CONTROLLER);

		getPanelControlled().getLyricsContainer().setLineWrap(false);
		getPanelControlled().getLyricsContainer().setText(lyrics);
		getPanelControlled().getLyricsContainer().setCaretPosition(0);

		getPanelControlled().getCopyLyricToClipboard().setEnabled(lyrics != null && !lyrics.trim().isEmpty());

		// Set query string
		searchVideoQuery = StringUtils.getString(audioObject.getArtist(), " ", audioObject.getTitleOrFileName());
	}

	/**
	 * Sets the wiki information.
	 * 
	 * @param wikiText
	 *            the wiki text
	 * @param wikiURL
	 *            the wiki url
	 */
	public void setWikiInformation(String wikiText, String wikiURL) {
		getPanelControlled().getArtistWikiAbstract().setText(wikiText);
		getPanelControlled().getArtistWikiAbstract().setCaretPosition(0);
		getPanelControlled().getArtistWikiReadMore().setText(LanguageTool.getString("READ_MORE"), wikiURL);
	}

	/**
	 * Updates panel with audio object information.
	 * 
	 * @param ao
	 *            the audio object
	 */
	public void updatePanel(AudioObject ao) {
		getLogger().debug(LogCategories.CONTROLLER);

		if (Kernel.getInstance().state.isUseAudioScrobbler()) {
			if (ao == null) {
				// Clear all tabs
				AudioScrobblerServiceHandler.getInstance().clear();
				showAllTabsDisabled();
			} else {
				if (ao instanceof AudioFile)
					// Audio File -> show all tabs
					getPanelControlled().showAllTabs(true);
				else if (ao instanceof Radio) {
					// Radio with song information -> show all tabs
					if (((Radio) ao).isSongInfoAvailable()) {
						getPanelControlled().showAllTabs(LanguageTool.getString("RADIO"), ImageLoader.RADIO_LITTLE, true);
					} else {
						// Radio without song information -> show only first tab
						getPanelControlled().showFirstTab(LanguageTool.getString("RADIO"), ImageLoader.RADIO_LITTLE);
					}
				} else
					// Podcast -> show only first tab
					getPanelControlled().showFirstTab(LanguageTool.getString("PODCAST_FEED"), ImageLoader.RSS_LITTLE);
				AudioScrobblerServiceHandler.getInstance().retrieveInfo(ao);
			}
		}
	}

	/**
	 * Delegate method to show all tabs disabled
	 */
	public void showAllTabsDisabled() {
		getPanelControlled().showAllTabs(false);
	}
}
