/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.controllers.editPreferencesDialog;

import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

import javax.swing.DefaultListModel;
import javax.swing.SwingConstants;

import net.sourceforge.atunes.gui.views.dialogs.editPreferences.AudioScrobblerPanel;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.DevicePanel;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.EditPreferencesDialog;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.GeneralPanel;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.InternetPanel;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.LastFmPanel;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.NavigatorPanel;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.OSDPanel;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.PlayerPanel;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.PodcastFeedPanel;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.PreferencesPanel;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.RadioPanel;
import net.sourceforge.atunes.gui.views.dialogs.editPreferences.RepositoryPanel;
import net.sourceforge.atunes.kernel.ControllerProxy;
import net.sourceforge.atunes.kernel.Kernel;
import net.sourceforge.atunes.kernel.controllers.model.DialogController;
import net.sourceforge.atunes.kernel.handlers.AudioScrobblerServiceHandler;
import net.sourceforge.atunes.kernel.handlers.HotkeyHandler;
import net.sourceforge.atunes.kernel.handlers.PlayerHandler;
import net.sourceforge.atunes.kernel.handlers.PodcastFeedHandler;
import net.sourceforge.atunes.kernel.handlers.RadioHandler;
import net.sourceforge.atunes.kernel.handlers.SystemTrayHandler;
import net.sourceforge.atunes.kernel.handlers.VisualHandler;
import net.sourceforge.atunes.kernel.modules.device.DeviceConnectionMonitor;
import net.sourceforge.atunes.kernel.modules.state.ApplicationState;
import net.sourceforge.atunes.kernel.modules.state.beans.LocaleBean;
import net.sourceforge.atunes.kernel.modules.state.beans.ProxyBean;
import net.sourceforge.atunes.kernel.utils.SystemProperties;
import net.sourceforge.atunes.kernel.utils.SystemProperties.OperatingSystem;
import net.sourceforge.atunes.utils.LanguageTool;
import net.sourceforge.atunes.utils.StringUtils;
import net.sourceforge.atunes.utils.log4j.LogCategories;

/**
 * The Class EditPreferencesDialogController.
 */
public class EditPreferencesDialogController extends DialogController<EditPreferencesDialog> {

	/** The Constant GENERAL. */
	private static final String GENERAL = LanguageTool.getString("GENERAL");

	/** The Constant REPOSITORY. */
	private static final String REPOSITORY = LanguageTool.getString("REPOSITORY");

	/** The Constant PLAYER. */
	private static final String PLAYER = LanguageTool.getString("PLAYER");

	/** The Constant NAVIGATOR. */
	private static final String NAVIGATOR = LanguageTool.getString("NAVIGATOR");

	/** The Constant OSD. */
	private static final String OSD = LanguageTool.getString("OSD");

	/** The Constant AUDIO_SCROBBLER. */
	private static final String AUDIO_SCROBBLER = LanguageTool.getString("AUDIO_SCROBBLER");

	/** The Constant INTERNET. */
	private static final String INTERNET = LanguageTool.getString("INTERNET");

	/** The Constant LASTFM. */
	private static final String LASTFM = "Last.fm";

	/** The Constant DEVICE. */
	private static final String DEVICE = LanguageTool.getString("DEVICE");

	/** The Constant RADIO. */
	private static final String RADIO = LanguageTool.getString("RADIO");

	/** The Constant PODCAST_FEED. */
	private static final String PODCAST_FEED = LanguageTool.getString("PODCAST_FEEDS");

	/** The tree nodes. */
	private String[] treeNodes = new String[] { GENERAL, REPOSITORY, PLAYER, NAVIGATOR, OSD, AUDIO_SCROBBLER, INTERNET, LASTFM, DEVICE, RADIO, PODCAST_FEED };

	/** The internet panel. */
	private InternetPanel internetPanel;

	/** The state. */
	private ApplicationState state = Kernel.getInstance().state;

	/** The panels. */
	private PreferencesPanel[] panels = new PreferencesPanel[] { getGeneralPanel(), getRepositoryPanel(), getPlayerPanel(), getNavigatorPanel(), getOSDPanel(),
			getAudioScrobblerPanel(), getInternetPanel(), getLastFmPanel(), getDevicePanel(), getRadioPanel(), getPodcastFeedPanel() };

	/**
	 * Instantiates a new edits the preferences dialog controller.
	 */
	public EditPreferencesDialogController() {
		super(VisualHandler.getInstance().getEditPreferencesDialog());
		// addBindings();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#addBindings()
	 */
	@Override
	protected void addBindings() {
		EditPreferencesDialogListener listener = new EditPreferencesDialogListener(getDialogControlled(), this);
		getDialogControlled().getList().addListSelectionListener(listener);
		getDialogControlled().getCancel().addActionListener(listener);
		getDialogControlled().getOk().addActionListener(listener);
		getDialogControlled().getAudioScrobblerPanel().getClearCache().addActionListener(listener);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#addStateBindings()
	 */
	@Override
	protected void addStateBindings() {
		// Nothing to do
	}

	/**
	 * Builds the list.
	 */
	private void buildList() {
		DefaultListModel listModel = new DefaultListModel();

		for (String s : treeNodes)
			listModel.addElement(s);

		getDialogControlled().setListModel(listModel);
		getDialogControlled().getList().setSelectedIndex(0);
	}

	/**
	 * Gets the audio scrobbler panel.
	 * 
	 * @return the audio scrobbler panel
	 */
	private PreferencesPanel getAudioScrobblerPanel() {
		AudioScrobblerPanel panel = new AudioScrobblerPanel();
		panel.setActivateAudioScrobbler(state.isUseAudioScrobbler());
		panel.setSavePictures(state.isSavePictureFromAudioScrobbler());
		return panel;
	}

	/**
	 * Gets the device panel.
	 * 
	 * @return the device panel
	 */
	private DevicePanel getDevicePanel() {
		DevicePanel panel = new DevicePanel();
		panel.setDefaultDeviceLocation(state.getDefaultDeviceLocation());
		panel.setFlatStructureRadioButton(state.isFlatStructure());
		panel.setArtistStructureRadioButton(state.isArtistStructure());
		panel.setFullStructureRadioButton(state.isFullStructure());
		return panel;
	}

	/**
	 * Gets the general panel.
	 * 
	 * @return the general panel
	 */
	private PreferencesPanel getGeneralPanel() {
		GeneralPanel panel = new GeneralPanel();
		panel.setShowTitle(state.isShowTitle());
		panel.setWindowType(state.isMultipleWindow() ? LanguageTool.getString("MULTIPLE_WINDOW") : LanguageTool.getString("STANDARD_WINDOW"));
		panel.setLanguage(LanguageTool.getLanguageSelected());
		panel.setShowIconTray(state.isShowSystemTray());
		panel.setShowTrayPlayer(state.isShowTrayPlayer());
		panel.setTheme(state.getSkin());
		panel.setUseDefaultFont(state.isUseDefaultFont());
		return panel;
	}

	/**
	 * Gets the internet panel.
	 * 
	 * @return the internet panel
	 */
	private PreferencesPanel getInternetPanel() {
		InternetPanel panel = new InternetPanel();
		internetPanel = panel;
		panel.setConfiguration(state.getProxy());
		return panel;
	}

	/**
	 * Gets the last fm panel.
	 * 
	 * @return the last fm panel
	 */
	private PreferencesPanel getLastFmPanel() {
		LastFmPanel panel = new LastFmPanel();
		panel.setLastFmUser(state.getLastFmUser());
		panel.setLasFmPassword(state.getLastFmPassword());
		return panel;
	}

	/**
	 * Gets the navigator panel.
	 * 
	 * @return the navigator panel
	 */
	private PreferencesPanel getNavigatorPanel() {
		NavigatorPanel panel = new NavigatorPanel();
		panel.setShowFavorites(state.isShowFavoritesInNavigator());
		panel.setShowAlbumToolTip(state.isShowAlbumTooltip());
		panel.setAlbumToolTipDelay(state.getAlbumTooltipDelay());
		panel.setUseSmartTagViewSorting(state.isUseSmartTagViewSorting());
		panel.setShowNavigatorTabsAtLeft(state.isShowNavigatorTabsAtLeft());
		panel.setShowNavigatorTabsText(state.isShowNavigatorTabsText());
		return panel;
	}

	/**
	 * Gets the oSD panel.
	 * 
	 * @return the oSD panel
	 */
	private PreferencesPanel getOSDPanel() {
		OSDPanel panel = new OSDPanel();
		panel.setAnimateOSD(state.isAnimateOSD());
		panel.setOSDDuration(state.getOsdDuration());
		panel.setTransparentOSD(state.isTransparentOSD());
		panel.getTransparentOSDCheckBox().setEnabled(SystemProperties.isJava6Update10OrLater);
		return panel;
	}

	/**
	 * Gets the player panel.
	 * 
	 * @return the player panel
	 */
	private PreferencesPanel getPlayerPanel() {
		PlayerPanel panel = new PlayerPanel();
		panel.setUseNormalisation(state.isUseNormalisation());
		panel.setPlayAtStartup(state.isPlayAtStartup());
		panel.setUseFadeAway(state.isUseFadeAway());
		panel.setCacheFilesBeforePlaying(state.isCacheFilesBeforePlaying());
		panel.setEnableHotkeys(state.isEnableHotkeys());
		panel.setUseShortPathNames(state.isUseShortPathNames());
		panel.getUseShortPathNames().setEnabled(SystemProperties.OS == OperatingSystem.WINDOWS);
		panel.getEnableGlobalHotkeys().setEnabled(HotkeyHandler.areHotkeysAndIntellitypeSupported());
		return panel;
	}

	/**
	 * Gets the podcast feed panel.
	 * 
	 * @return the podcast feed panel
	 */
	private PodcastFeedPanel getPodcastFeedPanel() {
		PodcastFeedPanel panel = new PodcastFeedPanel();
		panel.setRetrievalInterval(state.getPodcastFeedEntriesRetrievalInterval());
		panel.setDownloadPath(state.getPodcastFeedEntryDownloadPath());
		panel.setUseDownloadedPodcastFeedEntries(state.isUseDownloadedPodcastFeedEntries());
		panel.setRemovePodcastFeedEntriesRemovedFromPodcastFeed(state.isRemovePodcastFeedEntriesRemovedFromPodcastFeed());
		return panel;
	}

	/**
	 * Gets the radio panel.
	 * 
	 * @return the radio panel
	 */
	private RadioPanel getRadioPanel() {
		RadioPanel panel = new RadioPanel();
		panel.setReadInfoFromRadioStream(state.isReadInfoFromRadioStream());
		panel.setShowAllRadioStations(state.isShowAllRadioStations());
		return panel;
	}

	/**
	 * Gets the repository panel.
	 * 
	 * @return the repository panel
	 */
	private PreferencesPanel getRepositoryPanel() {
		RepositoryPanel panel = new RepositoryPanel();
		panel.setRefreshTime(state.getAutoRepositoryRefreshTime());
		panel.setSaveRepositoryAsXml(state.isSaveRepositoryAsXml());
		return panel;
	}

	/**
	 * No errors.
	 * 
	 * @return true, if successful
	 */
	boolean noErrors() {
		return internetPanel.getResult() != null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#notifyReload()
	 */
	@Override
	protected void notifyReload() {
		// Nothing to do
	}

	/**
	 * Process preferences.
	 * 
	 * @return true if application needs to be restarted to apply some changes
	 */
	@SuppressWarnings("boxing")
	boolean processPreferences() {
		boolean needRestart = false;
		// Fetch result from panels
		Map<String, Object> result = new HashMap<String, Object>();
		for (PreferencesPanel p : panels)
			result.putAll(p.getResult());

		// Set properties
		state.setShowTitle((Boolean) result.get(LanguageTool.getString("SHOW_TITLE")));

		boolean oldMultipleWindow = state.isMultipleWindow();
		boolean newMultipleWindow = result.get(LanguageTool.getString("WINDOW_TYPE")).equals(LanguageTool.getString("MULTIPLE_WINDOW"));
		state.setMultipleWindow(newMultipleWindow);
		if (oldMultipleWindow != newMultipleWindow)
			needRestart = true;

		LocaleBean oldLocale = state.getLocale();
		LocaleBean newLocale = new LocaleBean((Locale) result.get(LanguageTool.getString("LANGUAGE")));
		state.setLocale(newLocale);
		if (!oldLocale.equals(newLocale))
			needRestart = true;

		state.setUseDefaultFont((Boolean) result.get(LanguageTool.getString("USE_DEFAULT_FONT")));
		state.setShowSystemTray((Boolean) result.get(LanguageTool.getString("SHOW_TRAY_ICON")));
		state.setShowTrayPlayer((Boolean) result.get(LanguageTool.getString("SHOW_TRAY_PLAYER")));

		String oldTheme = state.getSkin();
		String newTheme = (String) result.get(LanguageTool.getString("THEME"));
		state.setSkin(newTheme);
		if (!oldTheme.equals(newTheme))
			needRestart = true;

		state.setUseNormalisation((Boolean) result.get(LanguageTool.getString("USE_NORMALISATION")));
		state.setPlayAtStartup((Boolean) result.get(LanguageTool.getString("PLAY_AT_STARTUP")));
		state.setUseFadeAway((Boolean) result.get(LanguageTool.getString("USE_FADE_AWAY")));
		state.setUseShortPathNames((Boolean) result.get(LanguageTool.getString("USE_SHORT_PATH_NAMES_FOR_MPLAYER")));
		state.setEnableHotkeys((Boolean) result.get(LanguageTool.getString("ENABLE_GOLBAL_HOTKEYS")));
		state.setCacheFilesBeforePlaying((Boolean) result.get(LanguageTool.getString("CACHE_FILES_BEFORE_PLAYING")));

		state.setAutoRepositoryRefreshTime((Integer) result.get(LanguageTool.getString("REPOSITORY_REFRESH_TIME")));
		state.setSaveRepositoryAsXml((Boolean) result.get(LanguageTool.getString("SAVE_REPOSITORY_AS_XML")));

		state.setShowFavoritesInNavigator((Boolean) result.get(LanguageTool.getString("SHOW_FAVORITES")));
		state.setShowAlbumTooltip((Boolean) result.get(LanguageTool.getString("SHOW_ALBUM_TOOLTIP")));
		state.setAlbumTooltipDelay((Integer) result.get(LanguageTool.getString("ALBUM_TOOLTIP_DELAY")));
		state.setUseSmartTagViewSorting((Boolean) result.get(LanguageTool.getString("USE_SMART_TAG_VIEW_SORTING")));
		state.setShowNavigatorTabsAtLeft((Boolean) result.get(LanguageTool.getString("SHOW_NAVIGATION_TABS_AT_LEFT")));
		state.setShowNavigatorTabsText((Boolean) result.get(LanguageTool.getString("SHOW_NAVIGATION_TABS_TEXT")));

		state.setAnimateOSD((Boolean) result.get(LanguageTool.getString("ANIMATE_OSD")));
		state.setOsdDuration((Integer) result.get(LanguageTool.getString("OSD_DURATION")));
		state.setTransparentOSD((Boolean) result.get(LanguageTool.getString("TRANSPARENT_OSD")));

		state.setUseAudioScrobbler((Boolean) result.get(LanguageTool.getString("ACTIVATE_AUDIO_SCROBBLER")));
		state.setSavePictureFromAudioScrobbler((Boolean) result.get(LanguageTool.getString("SAVE_PICTURES_TO_AUDIO_FOLDERS")));
		state.setProxy((ProxyBean) result.get("PROXY"));

		state.setLastFmUser((String) result.get(LanguageTool.getString("LASTFM_USER")));
		state.setLastFmPassword((String) result.get(LanguageTool.getString("LASTFM_PASSWORD")));
		state.setLastFmEnabled(true);

		state.setDefaultDeviceLocation((String) result.get(LanguageTool.getString("DEVICE_DEFAULT_LOCATION")));
		state.setFlatStructure((Boolean) result.get(LanguageTool.getString("FLAT")));
		state.setArtistStructure((Boolean) result.get(LanguageTool.getString("ARTIST")));
		state.setFullStructure((Boolean) result.get(StringUtils.getString(LanguageTool.getString("ARTIST"), " / ", LanguageTool.getString("ALBUM"))));

		state.setReadInfoFromRadioStream((Boolean) result.get(LanguageTool.getString("READ_INFO_FROM_RADIO_STREAM")));
		state.setShowAllRadioStations((Boolean) result.get(LanguageTool.getString("SHOW_ALL_RADIO_STATIONS")));

		state.setPodcastFeedEntriesRetrievalInterval((Long) result.get(LanguageTool.getString("PODCAST_FEED_ENTRIES_RETRIEVAL_INTERVAL")));
		state.setPodcastFeedEntryDownloadPath((String) result.get(LanguageTool.getString("PODCAST_FEED_ENTRIES_DOWNLOAD_FOLDER")));
		state.setUseDownloadedPodcastFeedEntries((Boolean) result.get(LanguageTool.getString("USE_DOWNLOADED_PODCAST_FEED_ENTRIES")));
		state.setRemovePodcastFeedEntriesRemovedFromPodcastFeed((Boolean) result.get(LanguageTool.getString("REMOVE_PODCAST_FEED_ENTRIES_REMOVED_FROM_PODCAST_FEED")));

		return needRestart;
	}

	/**
	 * Start.
	 */
	public void start() {
		getLogger().debug(LogCategories.CONTROLLER);

		getDialogControlled().setPanels(panels);
		buildList();
		updateProperties();

		addBindings();

		getDialogControlled().setVisible(true);

	}

	/**
	 * Update application with new configuration
	 */
	void updateApplication() {
		// Show or hide audioscrobbler panel
		VisualHandler.getInstance().showAudioScrobblerPanel(state.isUseAudioScrobbler(), true);

		// Set location for navigator tabs (left or top)
		VisualHandler.getInstance().getNavigationPanel().getTabbedPane().setTabPlacement(state.isShowNavigatorTabsAtLeft() ? SwingConstants.LEFT : SwingConstants.TOP);

		// Set text for navigator tabs
		VisualHandler.getInstance().getNavigationPanel().setNavigatorTabsText(state.isShowNavigatorTabsText());

		// Once done graphic changes, repaint the window
		VisualHandler.getInstance().repaint();

		ControllerProxy.getInstance().getOSDDialogController().setTransparent(state.isTransparentOSD());
		ControllerProxy.getInstance().getNavigationController().refreshRepositoryViewTreeContent();
		PlayerHandler.getInstance().setUseNormalisation(state.isUseNormalisation());
		AudioScrobblerServiceHandler.getInstance().updateService(state.getProxy(), Kernel.getInstance().state.getLastFmUser(), state.getLastFmPassword());
		SystemTrayHandler.getInstance().setTrayIconVisible(state.isShowSystemTray());
		SystemTrayHandler.getInstance().setTrayPlayerVisible(state.isShowTrayPlayer());
		DeviceConnectionMonitor.startMonitor();
		PodcastFeedHandler.getInstance().setPodcastFeedEntryRetrievalInterval(state.getPodcastFeedEntriesRetrievalInterval());
		HotkeyHandler.getInstance().enableHotkeys(state.isEnableHotkeys());
		RadioHandler.getInstance().refresh();
	}

	// Updates properties that may be changed
	/**
	 * Update properties.
	 */
	private void updateProperties() {
		((AudioScrobblerPanel) panels[5]).setActivateAudioScrobbler(state.isUseAudioScrobbler());
	}

}
