/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.controllers.playListControls;

import net.sourceforge.atunes.gui.views.panels.PlayListControlsPanel;
import net.sourceforge.atunes.kernel.controllers.model.PanelController;

/**
 * The Class PlayListControlsController.
 */
public class PlayListControlsController extends PanelController<PlayListControlsPanel> {

	/**
	 * Instantiates a new play list controls controller.
	 * 
	 * @param panel
	 *            the panel
	 */
	public PlayListControlsController(PlayListControlsPanel panel) {
		super(panel);
		addBindings();
		addStateBindings();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#addBindings()
	 */
	@Override
	protected void addBindings() {
		PlayListControlsListener listener = new PlayListControlsListener(getPanelControlled());

		getPanelControlled().getSearchFilter().addActionListener(listener);
		getPanelControlled().getSavePlaylistButton().addActionListener(listener);
		getPanelControlled().getLoadPlaylistButton().addActionListener(listener);
		getPanelControlled().getTopButton().addActionListener(listener);
		getPanelControlled().getUpButton().addActionListener(listener);
		getPanelControlled().getDeleteButton().addActionListener(listener);
		getPanelControlled().getDownButton().addActionListener(listener);
		getPanelControlled().getBottomButton().addActionListener(listener);
		getPanelControlled().getInfoButton().addActionListener(listener);
		getPanelControlled().getClearButton().addActionListener(listener);
		getPanelControlled().getFavoriteSong().addActionListener(listener);
		getPanelControlled().getFavoriteAlbum().addActionListener(listener);
		getPanelControlled().getFavoriteArtist().addActionListener(listener);
		getPanelControlled().getArtistButton().addActionListener(listener);
		getPanelControlled().getAlbumButton().addActionListener(listener);
		getPanelControlled().getScrollPlaylistToCurrentSongButton().addActionListener(listener);
		getPanelControlled().getShufflePlaylist().addActionListener(listener);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#addStateBindings()
	 */
	@Override
	protected void addStateBindings() {
		disablePlayListControls(true, false);
	}

	/**
	 * Disable play list controls.
	 * 
	 * @param disable
	 *            the disable
	 * @param radioOrPodcastFeedEntrySelected
	 *            the radio or podcast feed entry selected
	 */
	public void disablePlayListControls(boolean disable, boolean radioOrPodcastFeedEntrySelected) {
		getPanelControlled().getSearchFilter().setEnabled(true);
		getPanelControlled().getInfoButton().setEnabled(!disable);
		getPanelControlled().getDeleteButton().setEnabled(!disable);
		getPanelControlled().getClearButton().setEnabled(true);
		getPanelControlled().getTopButton().setEnabled(!disable);
		getPanelControlled().getUpButton().setEnabled(!disable);
		getPanelControlled().getDownButton().setEnabled(!disable);
		getPanelControlled().getBottomButton().setEnabled(!disable);
		getPanelControlled().getFavoritePopup().setEnabled(!disable && !radioOrPodcastFeedEntrySelected);
		getPanelControlled().getArtistButton().setEnabled(!disable && !radioOrPodcastFeedEntrySelected);
		getPanelControlled().getAlbumButton().setEnabled(!disable && !radioOrPodcastFeedEntrySelected);
	}

	/**
	 * Enable save button.
	 * 
	 * @param enable
	 *            the enable
	 */
	public void enableSaveButton(boolean enable) {
		getPanelControlled().getSavePlaylistButton().setEnabled(enable);
	}

	/**
	 * Enable shuffle button.
	 * 
	 * @param enable
	 *            the enable
	 */
	public void enableShuffleButton(boolean enable) {
		getPanelControlled().getShufflePlaylist().setEnabled(enable);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.kernel.controllers.model.Controller#notifyReload()
	 */
	@Override
	protected void notifyReload() {
		// Nothing to do
	}
}
