/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.modules.audioscrobbler;

import java.awt.Image;
import java.util.List;

import javax.swing.SwingUtilities;

/**
 * The Class AudioScrobblerCoversRunnable.
 */
public class AudioScrobblerCoversRunnable implements Runnable {

	/** The listener. */
	AudioScrobblerListener listener;

	/** The service. */
	private AudioScrobblerService service;

	/** The albums. */
	private List<AudioScrobblerAlbum> albums;

	/** The interrupted. */
	private volatile boolean interrupted;

	/** The id. */
	long id;

	/**
	 * Instantiates a new audio scrobbler covers runnable.
	 * 
	 * @param listener
	 *            the listener
	 * @param service
	 *            the service
	 * @param albums
	 *            the albums
	 * @param id
	 *            the id
	 */
	public AudioScrobblerCoversRunnable(AudioScrobblerListener listener, AudioScrobblerService service, List<AudioScrobblerAlbum> albums, long id) {
		this.listener = listener;
		this.service = service;
		this.albums = albums;
		this.id = id;
	}

	/**
	 * Interrupt.
	 */
	protected void interrupt() {
		interrupted = true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Runnable#run()
	 */
	@Override
	public void run() {
		if (albums != null) {
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					listener.notifyStartRetrievingCovers(id);
				}
			});
			for (int i = 0; i < albums.size(); i++) {
				final Image img;
				final AudioScrobblerAlbum album = albums.get(i);
				if (!interrupted) {
					img = service.getImage(album);
				} else {
					img = null;
				}

				if (!interrupted) {
					SwingUtilities.invokeLater(new Runnable() {
						@Override
						public void run() {
							listener.notifyCoverRetrieved(album, img, id);
						}
					});
				}
			}
		}
	}
}
