/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.modules.audioscrobbler;

import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

/**
 * The Class AudioScrobblerSimilarArtists.
 */
public class AudioScrobblerSimilarArtists {

	/** The Constant MAX_SIMILAR_ARTISTS. */
	public static final int MAX_SIMILAR_ARTISTS = 15;

	/** The artist name. */
	private String artistName;

	/** The picture. */
	private String picture;

	/** The artists. */
	private List<AudioScrobblerArtist> artists;

	/**
	 * Gets the similar artists.
	 * 
	 * @param xml
	 *            the xml
	 * 
	 * @return the similar artists
	 */
	protected static AudioScrobblerSimilarArtists getSimilarArtists(Document xml) {
		Element el = (Element) xml.getElementsByTagName("similarartists").item(0);
		AudioScrobblerSimilarArtists similar = new AudioScrobblerSimilarArtists();
		similar.artistName = el.getAttribute("artist");
		similar.picture = el.getAttribute("picture");

		similar.artists = new ArrayList<AudioScrobblerArtist>();
		NodeList artists = el.getElementsByTagName("artist");
		for (int i = 0; i < artists.getLength(); i++) {
			if (i == MAX_SIMILAR_ARTISTS)
				break;
			Element e = (Element) artists.item(i);
			similar.artists.add(AudioScrobblerArtist.getArtist(e));
		}

		return similar;
	}

	/**
	 * Gets the artist name.
	 * 
	 * @return the artist name
	 */
	public String getArtistName() {
		return artistName;
	}

	/**
	 * Gets the artists.
	 * 
	 * @return the artists
	 */
	public List<AudioScrobblerArtist> getArtists() {
		return artists;
	}

	/**
	 * Gets the picture.
	 * 
	 * @return the picture
	 */
	public String getPicture() {
		return picture;
	}

	/**
	 * Sets the artist name.
	 * 
	 * @param artistName
	 *            the artistName to set
	 */
	public void setArtistName(String artistName) {
		this.artistName = artistName;
	}

	/**
	 * Sets the artists.
	 * 
	 * @param artists
	 *            the artists to set
	 */
	public void setArtists(List<AudioScrobblerArtist> artists) {
		this.artists = artists;
	}

	/**
	 * Sets the picture.
	 * 
	 * @param picture
	 *            the picture to set
	 */
	public void setPicture(String picture) {
		this.picture = picture;
	}

}
