/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.modules.lyrics;

import javax.swing.SwingUtilities;

import net.sourceforge.atunes.kernel.handlers.AudioScrobblerServiceHandler;
import net.sourceforge.atunes.model.AudioObject;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * The Class LyricsRunnable.
 */
public class LyricsRunnable implements Runnable {

	/** The audio object. */
	AudioObject audioObject;

	/** The retrieved lyrics */
	String lyrics = null;

	/** The id. */
	long id;

	/**
	 * Instantiates a new lyrics runnable.
	 * 
	 * @param audioObject
	 *            the audio object
	 * @param id
	 *            the id
	 */
	public LyricsRunnable(AudioObject audioObject, long id) {
		this.audioObject = audioObject;
		this.id = id;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Runnable#run()
	 */
	@Override
	public void run() {
		// First check if tag contains the lyrics. Favour this over internet services.
		if (!audioObject.getLyrics().trim().isEmpty()) {
			lyrics = audioObject.getLyrics();
		}
		// Query internet service for lyrics
		else {
			if (!audioObject.getTitle().trim().isEmpty() && !audioObject.getArtist().trim().isEmpty() && !audioObject.getArtist().equals(LanguageTool.getString("UNKNOWN_ARTIST"))) {
				lyrics = LyricsService.getLyrics(audioObject.getArtist().trim(), audioObject.getTitle().trim());
			}
		}
		if (lyrics != null)
			lyrics = lyrics.replaceAll("'", "\'");

		SwingUtilities.invokeLater(new Runnable() {
			@Override
			public void run() {
				AudioScrobblerServiceHandler.getInstance().notifyLyricsRetrieved(audioObject, lyrics, id);
			}
		});
	}

}
