/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.utils;

import java.io.File;
import java.io.IOException;

import net.sourceforge.atunes.utils.StringUtils;

import org.apache.commons.io.FileUtils;

/**
 * The Class TempFolder.
 */
public class TempFolder {

	/**
	 * Copies a file to temp folder.
	 * 
	 * @param srcFile
	 *            the src file
	 * 
	 * @return File object to copied file in temp folder
	 */
	public static File copyToTempFolder(File srcFile) {
		File destFile = new File(StringUtils.getString(SystemProperties.getTempFolder(), SystemProperties.fileSeparator, srcFile.getName()));
		try {
			FileUtils.copyFile(srcFile, destFile);
		} catch (IOException e) {
			return null;
		}
		return destFile;
	}

	/**
	 * Removes a file from temp folder.
	 * 
	 * @param tempFile
	 *            the temp file
	 * 
	 * @return true, if removes the file
	 */
	public static boolean removeFile(File tempFile) {
		return tempFile.delete();
	}

	/**
	 * Removes all files from temp folder.
	 */
	public static void removeAllFiles() {
		File tempFolder = new File(SystemProperties.getTempFolder());
		File[] files = tempFolder.listFiles();
		for (File f : files)
			f.delete();
	}
}
